@@ -83,8 +83,10 @@ def _state(ctx):
 @click.option('--memory-mb', help='Memory in MB', type=click.IntRange(1, None))
 @click.option('--cpu-vmhz', help='CPU in VMHz', type=click.IntRange(1, None))
 @click.option('--processes-count', help='Processes', type=click.IntRange(1, None))
+@click.option('--command', help='Start instance with custom command')
+@click.option('-e', '--env', help='Set custom environment variables', multiple=True)
 @click.pass_obj
-def start(ctx, app, zone_name, node, count, **kwargs):
+def start(ctx, app, zone_name, node, count, command, env, **kwargs):
     """
     Start one or more application instances
     """
@@ -117,18 +119,36 @@ def start(ctx, app, zone_name, node, count, **kwargs):
             resources[key] = val
     action('Starting {} instances on {}..'.format(count, node_name))
     for i in range(count):
-        data = {'actions_create': [{
-                'instance_name': generate_random_name('{}-{}-{}-'.format(
-                    app.repository_name, app.application_name, app.application_version.replace('.', '-'))[:24], 4),
-                'node_name': node_name,
-                'resources': resources,
-                'metadata': {
-                    'repository_name': app.repository_name,
-                    'application_name': app.application_name,
-                    'application_version': app.application_version,
-                    'zone_name': zone_name,
+        metadata = {
+            'repository_name': app.repository_name,
+            'application_name': app.application_name,
+            'application_version': app.application_version,
+            'zone_name': zone_name,
+        }
+        if command:
+            metadata['command'] = command
+        if env:
+            env_dict = {}
+            for pair in env:
+                try:
+                    key, val = pair.split('=', 1)
+                except:
+                    raise click.UsageError('Environment variables need to be specified as KEY=VAL')
+                env_dict[key] = val
+            metadata['env'] = env_dict
+        data = {
+            'actions_create': [
+                {
+                    'instance_name': generate_random_name('{}-{}-{}-'.format(
+                        app.repository_name, app.application_name, app.application_version.replace('.', '-'))[:24], 4),
+                    'node_name': node_name,
+                    'resources': resources,
+                    'metadata': metadata,
                 }
-                }], 'allow_partial_commit': False}
+            ],
+            'allow_partial_commit': False
+        }
+
         ctx.controller.put('/scheduler', data=data)
     ok()
 
