@@ -86,6 +86,20 @@ Please use the "login" command or edit the configuration file {} manually.'''.fo
         _state(ctx.obj)
 
 
+class ServiceName(click.ParamType):
+    name = 'ServiceName'
+
+    def convert(self, value, param, ctx):
+        if value not in CORE_DOMAINS:
+            for name, short_name in CORE_DOMAINS.items():
+                if value == short_name:
+                    value = name
+        if value not in CORE_DOMAINS:
+            self.fail('Unknown service "{}", valid service names are: {}'.format(
+                      value, ', '.join(sorted(CORE_DOMAINS.keys()))))
+        return value
+
+
 class Endpoints(click.ParamType):
     name = 'Endpoints'
 
@@ -175,12 +189,17 @@ Check your username/password and cluster domain address.''', bold=True, fg='yell
 
 
 @cli.command()
-@click.pass_obj
-def status(ctx):
+@click.option('-s', '--service', help='Only check certain services', metavar='NAME', multiple=True, type=ServiceName())
+@click.pass_context
+def status(click_ctx, service):
     """
-    Ping all core cluster services
+    Ping all core cluster services, will exit with exit code 0 if all tested services work
     """
+    exit_code = 0
+    ctx = click_ctx.obj
     for svc in ctx.all_services:
+        if service and svc.name not in service:
+            continue
         action('Checking {}..'.format(svc.name))
         has_errors = 0
         total = 0
@@ -196,8 +215,10 @@ def status(ctx):
         else:
             if has_errors:
                 error('{}/{} FAILED'.format(has_errors, total))
+                exit_code += 1
             else:
                 ok()
+    click_ctx.exit(exit_code)
 
 
 @cli.command()
