@@ -302,8 +302,9 @@ def networks(ctx):
 @click.argument('ipv6_subnet')
 @click.argument('ipv6_gateway')
 @click.option('--ipv6-dns', help='Use specific nameserver')
+@click.option('--ipv6-ntp', help='Use specific NTP server')
 @click.pass_obj
-def add_network(ctx, zone_name, location_name, ipv6_subnet, ipv6_gateway, ipv6_dns):
+def add_network(ctx, zone_name, location_name, ipv6_subnet, ipv6_gateway, ipv6_dns, ipv6_ntp):
     """
     Add a new network
     """
@@ -313,7 +314,9 @@ def add_network(ctx, zone_name, location_name, ipv6_subnet, ipv6_gateway, ipv6_d
         'ipv6_subnet_ip': ipv6_subnet_ip,
         'ipv6_subnet_prefixlen': ipv6_subnet_prefixlen,
         'ipv6_gateway': ipv6_gateway,
-        'ipv6_dns': ipv6_dns
+        'ipv6_dns': ipv6_dns or ipv6_gateway,
+        'ipv6_ntp': ipv6_ntp or ipv6_gateway,
+        'ipv6_routes': []
     }
     action('Adding network for zone {zone_name} and location {location_name} with subnet {ipv6_subnet}..', **vars())
     ctx.manager.put('/networks/{}/{}'.format(location_name, zone_name), data=data)
