@@ -181,6 +181,10 @@ class BaseService(ClusterService):
     def name(self):
         return self.service_name
 
+    @property
+    def short_name(self):
+        return CORE_DOMAINS.get(self.name, self.name)
+
     def status(self):
         if not self._endpoints:
             yield (None, False, 'no endpoints')
